@@ -95,7 +95,7 @@ def _del_jos_users(db, username):
 def _del_jos_user_usergroup_map(db, userID):
 
 	sql = "DELETE FROM `jos_user_usergroup_map` WHERE `user_id` = %s"
-	data - (userID)
+	data = (userID)
 	db.query_rowcount(sql, data)
 
 def _del_jos_core_acl_aro(db, userID):
@@ -515,7 +515,11 @@ def delhubuser(username, hubname = ""):
 	data = (username)
 	userID = db.query_selectscalar(sql, data)
 
-	if uidExists(username):
+	if userID:
+		print "deleting found user"
+
+		print userID
+
 		if hubzero.utilities.misc.JOOMLA_25:
 			_del_jos_user_usergroup_map(db, userID)
 		else:
@@ -525,6 +529,9 @@ def delhubuser(username, hubname = ""):
 		_del_jos_xprofiles(db, userID)
 		_del_jos_users(db, username)
 
+	else:
+			print "user not found"
+
 	delete_ldap_user(username)
 
 
@@ -545,7 +552,7 @@ def updateUserPW(username, password, updateCMS = True, updateLDAP = True, hubnam
 	elif '{MD5}' in password:
 		pw = password
 	else:
-		pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+		pw = '{MD5}*' # can user generate a value that will MD5 hash to '*'? We think not.
 
 	if updateCMS:
 		_update_jos_xprofiles_pw(db, userid, pw)
@@ -666,6 +673,8 @@ def _syncuser(username, hubname = "", syncAttributes = False):
 		attrsToSync['userPassword'] = user[0].userPassword
 	
 	if user:
+		
+		print ("adding user " + str(user[0].cn))
 		add_ldap_user2(user[0].cn,
 			           user[0].uid,
 			           user[0].uidNumber,
@@ -778,24 +787,30 @@ def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user =
 		#grab all users from ldap
 		ldapServer = hubzero.config.webconfig.getComponentParam("com_system", "ldap_primary")
 		l = ldap.initialize(ldapServer)
+		
 		l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 
-		if user == '*':
-			r = l.search_s("ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
-		else:
-			r = l.search_s("uid="+user+",ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
+		r = None
+		try:
+			if user == '*':
+				r = l.search_s("ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
+			else:
+				r = l.search_s("uid="+user+",ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
+		except ldap.NO_SUCH_OBJECT:
+			pass
 
-		for dn,entry in r:
-			uid = str(entry['uid'][0])
+		if r:
+			for dn,entry in r:
+				uid = str(entry['uid'][0])
 			
-			if uid not in usersFromDB:
-				if verbose:
-					print "deleting user '" + uid + "' from ldap"
-				try:
-					hubzero.utilities.user.delete_ldap_user(uid)
-				except ldap.NO_SUCH_OBJECT:
-					if debug:
-						print " user not found"
+				if uid not in usersFromDB:
+					if verbose:
+						print "deleting user '" + uid + "' from ldap"
+					try:
+						hubzero.utilities.user.delete_ldap_user(uid)
+					except ldap.NO_SUCH_OBJECT:
+						if debug:
+							print " user not found"
 
 	# now do a mass add of all users from db	
 	if user == '*':
